@@ -17,6 +17,7 @@
 #include <aws/common/clock.h>
 #include <aws/common/device_random.h>
 #include <aws/common/environment.h>
+#include <aws/common/json.h>
 #include <aws/common/string.h>
 #include <aws/common/system_info.h>
 #include <aws/http/connection.h>
@@ -476,18 +477,19 @@ lock_init_fail:
     return NULL;
 }
 
-void aws_s3_client_acquire(struct aws_s3_client *client) {
+struct aws_s3_client *aws_s3_client_acquire(struct aws_s3_client *client) {
     AWS_PRECONDITION(client);
 
     aws_ref_count_acquire(&client->ref_count);
+    return client;
 }
 
-void aws_s3_client_release(struct aws_s3_client *client) {
-    if (client == NULL) {
-        return;
+struct aws_s3_client *aws_s3_client_release(struct aws_s3_client *client) {
+    if (client != NULL) {
+        aws_ref_count_release(&client->ref_count);
     }
 
-    aws_ref_count_release(&client->ref_count);
+    return NULL;
 }
 
 static void s_s3_client_start_destroy(void *user_data) {
@@ -505,7 +507,7 @@ static void s_s3_client_start_destroy(void *user_data) {
 
         client->synced_data.active = false;
 
-        /* Prevent the client from cleaning up inbetween the mutex unlock/re-lock below.*/
+        /* Prevent the client from cleaning up in between the mutex unlock/re-lock below.*/
         client->synced_data.start_destroy_executing = true;
 
         aws_s3_client_unlock_synced_data(client);
@@ -830,8 +832,7 @@ struct aws_s3_meta_request *aws_s3_client_make_meta_request(
             aws_last_error(),
             aws_error_str(aws_last_error()));
 
-        aws_s3_meta_request_release(meta_request);
-        meta_request = NULL;
+        meta_request = aws_s3_meta_request_release(meta_request);
     } else {
         AWS_LOGF_INFO(AWS_LS_S3_CLIENT, "id=%p: Created meta request %p", (void *)client, (void *)meta_request);
     }
@@ -1165,8 +1166,7 @@ static void s_s3_client_process_work_default(struct aws_s3_client *client) {
 
             meta_request->client_process_work_threaded_data.scheduled = true;
         } else {
-            aws_s3_meta_request_release(meta_request);
-            meta_request = NULL;
+            meta_request = aws_s3_meta_request_release(meta_request);
         }
 
         aws_mem_release(client->allocator, meta_request_work);
@@ -1368,6 +1368,25 @@ void aws_s3_client_update_meta_requests_threaded(struct aws_s3_client *client) {
     }
 }
 
+static void s_s3_client_meta_request_finished_request(
+    struct aws_s3_client *client,
+    struct aws_s3_meta_request *meta_request,
+    struct aws_s3_request *request,
+    int error_code) {
+    AWS_PRECONDITION(client);
+    AWS_PRECONDITION(request);
+
+    if (request->tracked_by_client) {
+        /* BEGIN CRITICAL SECTION */
+        aws_s3_client_lock_synced_data(client);
+        aws_atomic_fetch_sub(&client->stats.num_requests_in_flight, 1);
+        s_s3_client_schedule_process_work_synced(client);
+        aws_s3_client_unlock_synced_data(client);
+        /* END CRITICAL SECTION */
+    }
+    aws_s3_meta_request_finished_request(meta_request, request, error_code);
+}
+
 static void s_s3_client_prepare_callback_queue_request(
     struct aws_s3_meta_request *meta_request,
     struct aws_s3_request *request,
@@ -1380,7 +1399,7 @@ static void s_s3_client_prepare_callback_queue_request(
     AWS_PRECONDITION(client);
 
     if (error_code != AWS_ERROR_SUCCESS) {
-        aws_s3_meta_request_finished_request(meta_request, request, error_code);
+        s_s3_client_meta_request_finished_request(client, meta_request, request, error_code);
 
         aws_s3_request_release(request);
         request = NULL;
@@ -1419,7 +1438,7 @@ void aws_s3_client_update_connections_threaded(struct aws_s3_client *client) {
         /* Unless the request is marked "always send", if this meta request has a finish result, then finish the request
          * now and release it. */
         if (!request->always_send && aws_s3_meta_request_has_finish_result(request->meta_request)) {
-            aws_s3_meta_request_finished_request(request->meta_request, request, AWS_ERROR_S3_CANCELED);
+            s_s3_client_meta_request_finished_request(client, request->meta_request, request, AWS_ERROR_S3_CANCELED);
 
             aws_s3_request_release(request);
             request = NULL;
@@ -1734,7 +1753,7 @@ reset_connection:
 
     aws_atomic_fetch_sub(&client->stats.num_requests_network_io[meta_request->type], 1);
 
-    aws_s3_meta_request_finished_request(meta_request, request, error_code);
+    s_s3_client_meta_request_finished_request(client, meta_request, request, error_code);
 
     if (connection->http_connection != NULL) {
         AWS_ASSERT(endpoint->http_connection_manager);
@@ -1856,17 +1875,82 @@ static void s_s3_client_prepare_request_callback_retry_request(
     }
 }
 
-/* Called by aws_s3_request when it has finished being destroyed */
-void aws_s3_client_notify_request_destroyed(struct aws_s3_client *client, struct aws_s3_request *request) {
-    AWS_PRECONDITION(client);
-    AWS_PRECONDITION(request);
+static void s_resume_token_ref_count_zero_callback(void *arg) {
+    struct aws_s3_meta_request_resume_token *token = arg;
 
-    if (request->tracked_by_client) {
-        /* BEGIN CRITICAL SECTION */
-        aws_s3_client_lock_synced_data(client);
-        aws_atomic_fetch_sub(&client->stats.num_requests_in_flight, 1);
-        s_s3_client_schedule_process_work_synced(client);
-        aws_s3_client_unlock_synced_data(client);
-        /* END CRITICAL SECTION */
+    aws_string_destroy(token->multipart_upload_id);
+
+    aws_mem_release(token->allocator, token);
+}
+
+struct aws_s3_meta_request_resume_token *aws_s3_meta_request_resume_token_new(struct aws_allocator *allocator) {
+    struct aws_s3_meta_request_resume_token *token =
+        aws_mem_calloc(allocator, 1, sizeof(struct aws_s3_meta_request_resume_token));
+
+    token->allocator = allocator;
+    aws_ref_count_init(&token->ref_count, token, s_resume_token_ref_count_zero_callback);
+
+    return token;
+}
+
+struct aws_s3_meta_request_resume_token *aws_s3_meta_request_resume_token_new_upload(
+    struct aws_allocator *allocator,
+    const struct aws_s3_upload_resume_token_options *options) {
+    AWS_PRECONDITION(allocator);
+    AWS_PRECONDITION(options);
+
+    struct aws_s3_meta_request_resume_token *token = aws_s3_meta_request_resume_token_new(allocator);
+    token->multipart_upload_id = aws_string_new_from_cursor(allocator, &options->upload_id);
+    token->part_size = options->part_size;
+    token->total_num_parts = options->total_num_parts;
+    token->num_parts_completed = options->num_parts_completed;
+    token->type = AWS_S3_META_REQUEST_TYPE_PUT_OBJECT;
+    return token;
+}
+
+struct aws_s3_meta_request_resume_token *aws_s3_meta_request_resume_token_acquire(
+    struct aws_s3_meta_request_resume_token *resume_token) {
+    if (resume_token) {
+        aws_ref_count_acquire(&resume_token->ref_count);
     }
+    return resume_token;
+}
+
+struct aws_s3_meta_request_resume_token *aws_s3_meta_request_resume_token_release(
+    struct aws_s3_meta_request_resume_token *resume_token) {
+    if (resume_token) {
+        aws_ref_count_release(&resume_token->ref_count);
+    }
+    return NULL;
+}
+
+enum aws_s3_meta_request_type aws_s3_meta_request_resume_token_type(
+    struct aws_s3_meta_request_resume_token *resume_token) {
+    AWS_FATAL_PRECONDITION(resume_token);
+    return resume_token->type;
+}
+
+size_t aws_s3_meta_request_resume_token_part_size(struct aws_s3_meta_request_resume_token *resume_token) {
+    AWS_FATAL_PRECONDITION(resume_token);
+    return resume_token->part_size;
+}
+
+size_t aws_s3_meta_request_resume_token_total_num_parts(struct aws_s3_meta_request_resume_token *resume_token) {
+    AWS_FATAL_PRECONDITION(resume_token);
+    return resume_token->total_num_parts;
+}
+
+size_t aws_s3_meta_request_resume_token_num_parts_completed(struct aws_s3_meta_request_resume_token *resume_token) {
+    AWS_FATAL_PRECONDITION(resume_token);
+    return resume_token->num_parts_completed;
+}
+
+struct aws_byte_cursor aws_s3_meta_request_resume_token_upload_id(
+    struct aws_s3_meta_request_resume_token *resume_token) {
+    AWS_FATAL_PRECONDITION(resume_token);
+    if (resume_token->type == AWS_S3_META_REQUEST_TYPE_PUT_OBJECT && resume_token->multipart_upload_id != NULL) {
+        return aws_byte_cursor_from_string(resume_token->multipart_upload_id);
+    }
+
+    return aws_byte_cursor_from_c_str("");
 }
