@@ -19,27 +19,26 @@
 #include <openssl/crypto.h>
 
 #include <stdlib.h>
-#if defined(BORINGSSL_FIPS)
+#if defined(BORINGSSL_FIPS) && defined(OPENSSL_ANDROID)
 #include <sys/mman.h>
 #include <unistd.h>
 #endif
 
+// On Windows place the bcm code in a specific section that uses Grouped Sections
+// to control the order. $b section will place bcm in between the start/end markers
+// which are in $a and $z.
+#if defined(BORINGSSL_FIPS) && defined(OPENSSL_WINDOWS)
+#pragma code_seg(".fipstx$b")
+#pragma data_seg(".fipsda$b")
+#pragma const_seg(".fipsda$b")
+#endif
+
 #include <openssl/digest.h>
 #include <openssl/hmac.h>
 #include <openssl/sha.h>
 
 #include "../internal.h"
 
-#include "cpucap/cpucap.c"
-#include "cpucap/cpu_aarch64_apple.c"
-#include "cpucap/cpu_aarch64_fuchsia.c"
-#include "cpucap/cpu_aarch64_linux.c"
-#include "cpucap/cpu_aarch64_win.c"
-#include "cpucap/cpu_arm_linux.c"
-#include "cpucap/cpu_arm.c"
-#include "cpucap/cpu_intel.c"
-#include "cpucap/cpu_ppc64le.c"
-
 #include "aes/aes.c"
 #include "aes/aes_nohw.c"
 #include "aes/key_wrap.c"
@@ -68,10 +67,17 @@
 #include "cipher/aead.c"
 #include "cipher/cipher.c"
 #include "cipher/e_aes.c"
-#include "cipher/e_des.c"
 #include "cipher/e_aesccm.c"
+
+#include "cpucap/cpu_aarch64_apple.c"
+#include "cpucap/cpu_aarch64_fuchsia.c"
+#include "cpucap/cpu_aarch64_linux.c"
+#include "cpucap/cpu_aarch64_win.c"
+#include "cpucap/cpu_arm_linux.c"
+#include "cpucap/cpu_intel.c"
+#include "cpucap/cpu_ppc64le.c"
+
 #include "cmac/cmac.c"
-#include "des/des.c"
 #include "dh/check.c"
 #include "dh/dh.c"
 #include "digest/digest.c"
@@ -98,6 +104,7 @@
 #include "evp/evp_ctx.c"
 #include "evp/p_ec.c"
 #include "evp/p_rsa.c"
+#include "hkdf/hkdf.c"
 #include "hmac/hmac.c"
 #include "md4/md4.c"
 #include "md5/md5.c"
@@ -107,7 +114,9 @@
 #include "modes/gcm.c"
 #include "modes/gcm_nohw.c"
 #include "modes/ofb.c"
+#include "modes/xts.c"
 #include "modes/polyval.c"
+#include "pbkdf/pbkdf.c"
 #include "rand/ctrdrbg.c"
 #include "rand/fork_detect.c"
 #include "rand/rand.c"
@@ -119,9 +128,11 @@
 #include "self_check/fips.c"
 #include "self_check/self_check.c"
 #include "service_indicator/service_indicator.c"
+#include "sha/keccak1600.c"
 #include "sha/sha1-altivec.c"
 #include "sha/sha1.c"
 #include "sha/sha256.c"
+#include "sha/sha3.c"
 #include "sha/sha512.c"
 #include "tls/kdf.c"
 
@@ -161,6 +172,23 @@ static void assert_within(const void *start, const void *symbol,
   BORINGSSL_FIPS_abort();
 }
 
+static void assert_not_within(const void *start, const void *symbol,
+                          const void *end) {
+  const uintptr_t start_val = (uintptr_t) start;
+  const uintptr_t symbol_val = (uintptr_t) symbol;
+  const uintptr_t end_val = (uintptr_t) end;
+
+  if (start_val >= symbol_val || symbol_val > end_val) {
+    return;
+  }
+
+  fprintf(
+      stderr,
+      "FIPS module spans unexpected symbol, expected %p < %p || %p > %p\n",
+      symbol, start, symbol, end);
+  BORINGSSL_FIPS_abort();
+}
+
 #if defined(OPENSSL_ANDROID) && defined(OPENSSL_AARCH64)
 static void BORINGSSL_maybe_set_module_text_permissions(int permission) {
   // Android may be compiled in execute-only-memory mode, in which case the
@@ -178,16 +206,23 @@ static void BORINGSSL_maybe_set_module_text_permissions(int permission) {
     perror("BoringSSL: mprotect");
   }
 }
-#else
-static void BORINGSSL_maybe_set_module_text_permissions(int permission) {}
 #endif  // !ANDROID
 
 #endif  // !ASAN
 
-static void __attribute__((constructor))
-BORINGSSL_bcm_power_on_self_test(void) {
+#if defined(_MSC_VER)
+#pragma section(".CRT$XCU", read)
+static void BORINGSSL_bcm_power_on_self_test(void);
+__declspec(allocate(".CRT$XCU")) void(*fips_library_init_constructor)(void) =
+    BORINGSSL_bcm_power_on_self_test;
+#else
+static void BORINGSSL_bcm_power_on_self_test(void) __attribute__ ((constructor));
+#endif
 
+static void BORINGSSL_bcm_power_on_self_test(void) {
+#if !defined(OPENSSL_NO_ASM)
   OPENSSL_cpuid_setup();
+#endif
 
   if (jent_entropy_init()) {
     fprintf(stderr, "CPU Jitter entropy RNG initialization failed.\n");
@@ -197,6 +232,23 @@ BORINGSSL_bcm_power_on_self_test(void) {
 #if !defined(OPENSSL_ASAN)
   // Integrity tests cannot run under ASAN because it involves reading the full
   // .text section, which triggers the global-buffer overflow detection.
+  if (!BORINGSSL_integrity_test()) {
+    goto err;
+  }
+#endif  // OPENSSL_ASAN
+
+  if (!boringssl_self_test_startup()) {
+    goto err;
+  }
+
+  return;
+
+err:
+  BORINGSSL_FIPS_abort();
+}
+
+#if !defined(OPENSSL_ASAN)
+int BORINGSSL_integrity_test(void) {
   const uint8_t *const start = BORINGSSL_bcm_text_start;
   const uint8_t *const end = BORINGSSL_bcm_text_end;
 
@@ -207,6 +259,8 @@ BORINGSSL_bcm_power_on_self_test(void) {
   assert_within(start, SHA256_Update, end);
   assert_within(start, ECDSA_do_verify, end);
   assert_within(start, EVP_AEAD_CTX_seal, end);
+  assert_not_within(start, OPENSSL_cleanse, end);
+  assert_not_within(start, CRYPTO_chacha_20, end);
 
 #if defined(BORINGSSL_SHARED_LIBRARY)
   const uint8_t *const rodata_start = BORINGSSL_bcm_rodata_start;
@@ -218,19 +272,20 @@ BORINGSSL_bcm_power_on_self_test(void) {
 #endif
 
   assert_within(rodata_start, kPrimes, rodata_end);
-  assert_within(rodata_start, des_skb, rodata_end);
   assert_within(rodata_start, kP256Params, rodata_end);
   assert_within(rodata_start, kPKCS1SigPrefixes, rodata_end);
 
   // Per FIPS 140-3 we have to perform the CAST of the HMAC used for integrity
-  // check before the integrity check itself. So we first call the self-test
+  // check before the integrity check itself. So we first call
+  // SHA-256 and HMAC-SHA256
   // before we calculate the hash of the module.
-  if (!boringssl_fips_self_test()) {
-    goto err;
-  }
 
   uint8_t result[SHA256_DIGEST_LENGTH];
   const EVP_MD *const kHashFunction = EVP_sha256();
+  if (!boringssl_self_test_sha256() ||
+      !boringssl_self_test_hmac_sha256()) {
+    return 0;
+  }
 
   static const uint8_t kHMACKey[64] = {0};
   unsigned result_len;
@@ -239,10 +294,12 @@ BORINGSSL_bcm_power_on_self_test(void) {
   if (!HMAC_Init_ex(&hmac_ctx, kHMACKey, sizeof(kHMACKey), kHashFunction,
                     NULL /* no ENGINE */)) {
     fprintf(stderr, "HMAC_Init_ex failed.\n");
-    goto err;
+    return 0;
   }
 
+#if defined(OPENSSL_ANDROID) && defined(OPENSSL_AARCH64)
   BORINGSSL_maybe_set_module_text_permissions(PROT_READ | PROT_EXEC);
+#endif
 #if defined(BORINGSSL_SHARED_LIBRARY)
   uint64_t length = end - start;
   HMAC_Update(&hmac_ctx, (const uint8_t *) &length, sizeof(length));
@@ -254,32 +311,28 @@ BORINGSSL_bcm_power_on_self_test(void) {
 #else
   HMAC_Update(&hmac_ctx, start, end - start);
 #endif
+#if defined(OPENSSL_ANDROID) && defined(OPENSSL_AARCH64)
   BORINGSSL_maybe_set_module_text_permissions(PROT_EXEC);
-
+#endif
   if (!HMAC_Final(&hmac_ctx, result, &result_len) ||
       result_len != sizeof(result)) {
     fprintf(stderr, "HMAC failed.\n");
-    goto err;
+    return 0;
   }
-  HMAC_CTX_cleanup(&hmac_ctx);
+  HMAC_CTX_cleanse(&hmac_ctx); // FIPS 140-3, AS05.10.
 
   const uint8_t *expected = BORINGSSL_bcm_text_hash;
 
   if (!check_test(expected, result, sizeof(result), "FIPS integrity test")) {
-    goto err;
+#if !defined(BORINGSSL_FIPS_BREAK_TESTS)
+    return 0;
+#endif
   }
 
-#else
-  if (!BORINGSSL_self_test()) {
-    goto err;
-  }
-#endif  // OPENSSL_ASAN
-
-  return;
-
-err:
-  BORINGSSL_FIPS_abort();
+  OPENSSL_cleanse(result, sizeof(result)); // FIPS 140-3, AS05.10.
+  return 1;
 }
+#endif  // OPENSSL_ASAN
 
 void BORINGSSL_FIPS_abort(void) {
   for (;;) {
