@@ -20,72 +20,70 @@
 #include "crypto/s2n_cipher.h"
 #include "crypto/s2n_fips.h"
 #include "crypto/s2n_openssl.h"
-
 #include "tls/s2n_crypto.h"
-
-#include "utils/s2n_safety.h"
 #include "utils/s2n_blob.h"
+#include "utils/s2n_safety.h"
 
 /* LibreSSL and BoringSSL support the cipher, but the interface is different from Openssl's. We
  * should define a separate s2n_cipher struct for LibreSSL and BoringSSL.
  */
 #if !defined(LIBRESSL_VERSION_NUMBER) && !defined(OPENSSL_IS_BORINGSSL)
-/* Symbols for AES-SHA1-CBC composite ciphers were added in Openssl 1.0.1
- * These composite ciphers exhibit erratic behavior in LibreSSL releases.
- */
-#if S2N_OPENSSL_VERSION_AT_LEAST(1,0,1)
-#define S2N_AES_SHA1_COMPOSITE_AVAILABLE
-#endif
-#if defined(AWSLC_API_VERSION) && (AWSLC_API_VERSION <= 17)
-#undef S2N_AES_SHA1_COMPOSITE_AVAILABLE
-#endif
-/* Symbols for AES-SHA256-CBC composite ciphers were added in Openssl 1.0.2
- * See https://www.openssl.org/news/cl102.txt
- * These composite ciphers exhibit erratic behavior in LibreSSL releases.
- */
-#if S2N_OPENSSL_VERSION_AT_LEAST(1,0,2)
-#define S2N_AES_SHA256_COMPOSITE_AVAILABLE
-#endif
-#if defined(AWSLC_API_VERSION) && (AWSLC_API_VERSION <= 17)
-#undef S2N_AES_SHA256_COMPOSITE_AVAILABLE
-#endif
+    /* Symbols for AES-SHA1-CBC composite ciphers were added in Openssl 1.0.1
+     * These composite ciphers exhibit erratic behavior in LibreSSL releases.
+     */
+    #if S2N_OPENSSL_VERSION_AT_LEAST(1, 0, 1)
+        #define S2N_AES_SHA1_COMPOSITE_AVAILABLE
+    #endif
+    #if defined(AWSLC_API_VERSION) && (AWSLC_API_VERSION <= 17)
+        #undef S2N_AES_SHA1_COMPOSITE_AVAILABLE
+    #endif
+    /* Symbols for AES-SHA256-CBC composite ciphers were added in Openssl 1.0.2
+     * See https://www.openssl.org/news/cl102.txt
+     * These composite ciphers exhibit erratic behavior in LibreSSL releases.
+     */
+    #if S2N_OPENSSL_VERSION_AT_LEAST(1, 0, 2)
+        #define S2N_AES_SHA256_COMPOSITE_AVAILABLE
+    #endif
+    #if defined(AWSLC_API_VERSION) && (AWSLC_API_VERSION <= 17)
+        #undef S2N_AES_SHA256_COMPOSITE_AVAILABLE
+    #endif
 #endif
 
 /* Silly accessors, but we avoid using version macro guards in multiple places */
 static const EVP_CIPHER *s2n_evp_aes_128_cbc_hmac_sha1(void)
 {
-    #if defined(S2N_AES_SHA1_COMPOSITE_AVAILABLE)
-        return EVP_aes_128_cbc_hmac_sha1();
-    #else
-        return NULL;
-    #endif
+#if defined(S2N_AES_SHA1_COMPOSITE_AVAILABLE)
+    return EVP_aes_128_cbc_hmac_sha1();
+#else
+    return NULL;
+#endif
 }
 
 static const EVP_CIPHER *s2n_evp_aes_256_cbc_hmac_sha1(void)
 {
-    #if defined(S2N_AES_SHA1_COMPOSITE_AVAILABLE)
-        return EVP_aes_256_cbc_hmac_sha1();
-    #else
-        return NULL;
-    #endif
+#if defined(S2N_AES_SHA1_COMPOSITE_AVAILABLE)
+    return EVP_aes_256_cbc_hmac_sha1();
+#else
+    return NULL;
+#endif
 }
 
 static const EVP_CIPHER *s2n_evp_aes_128_cbc_hmac_sha256(void)
 {
-    #if defined(S2N_AES_SHA256_COMPOSITE_AVAILABLE)
-        return EVP_aes_128_cbc_hmac_sha256();
-    #else
-        return NULL;
-    #endif
+#if defined(S2N_AES_SHA256_COMPOSITE_AVAILABLE)
+    return EVP_aes_128_cbc_hmac_sha256();
+#else
+    return NULL;
+#endif
 }
 
 static const EVP_CIPHER *s2n_evp_aes_256_cbc_hmac_sha256(void)
 {
-    #if defined(S2N_AES_SHA256_COMPOSITE_AVAILABLE)
-        return EVP_aes_256_cbc_hmac_sha256();
-    #else
-        return NULL;
-    #endif
+#if defined(S2N_AES_SHA256_COMPOSITE_AVAILABLE)
+    return EVP_aes_256_cbc_hmac_sha256();
+#else
+    return NULL;
+#endif
 }
 
 static uint8_t s2n_composite_cipher_aes128_sha_available(void)
@@ -128,18 +126,18 @@ static uint8_t s2n_composite_cipher_aes256_sha256_available(void)
 }
 
 static int s2n_composite_cipher_aes_sha_initial_hmac(struct s2n_session_key *key, uint8_t *sequence_number, uint8_t content_type,
-                                                     uint16_t protocol_version, uint16_t payload_and_eiv_len, int *extra)
+        uint16_t protocol_version, uint16_t payload_and_eiv_len, int *extra)
 {
     /* BoringSSL and AWS-LC(AWSLC_API_VERSION <= 17) do not support these composite ciphers with the existing EVP API, and they took out the
      * constants used below. This method should never be called with BoringSSL or AWS-LC(AWSLC_API_VERSION <= 17) because the isAvaliable checked
      * will fail. Instead of defining a possibly dangerous default or hard coding this to 0x16 error out with BoringSSL and AWS-LC(AWSLC_API_VERSION <= 17).
      */
 #if defined(OPENSSL_IS_BORINGSSL) || (defined(AWSLC_API_VERSION) && (AWSLC_API_VERSION <= 17))
-  POSIX_BAIL(S2N_ERR_NO_SUPPORTED_LIBCRYPTO_API);
+    POSIX_BAIL(S2N_ERR_NO_SUPPORTED_LIBCRYPTO_API);
 #else
     uint8_t ctrl_buf[S2N_TLS12_AAD_LEN];
     struct s2n_blob ctrl_blob = { .data = ctrl_buf, .size = S2N_TLS12_AAD_LEN };
-    struct s2n_stuffer ctrl_stuffer = {0};
+    struct s2n_stuffer ctrl_stuffer = { 0 };
     POSIX_GUARD(s2n_stuffer_init(&ctrl_stuffer, &ctrl_blob));
 
     POSIX_GUARD(s2n_stuffer_write_bytes(&ctrl_stuffer, sequence_number, S2N_TLS_SEQUENCE_NUM_LEN));
@@ -208,7 +206,6 @@ static int s2n_composite_cipher_aes_sha256_set_mac_write_key(struct s2n_session_
     return 0;
 }
 
-
 static int s2n_composite_cipher_aes128_sha_set_encryption_key(struct s2n_session_key *key, struct s2n_blob *in)
 {
     POSIX_ENSURE_EQ(in->size, 16);
@@ -303,17 +300,17 @@ static int s2n_composite_cipher_aes_sha_destroy_key(struct s2n_session_key *key)
     return 0;
 }
 
-struct s2n_cipher s2n_aes128_sha = {
+const struct s2n_cipher s2n_aes128_sha = {
     .key_material_size = 16,
     .type = S2N_COMPOSITE,
     .io.comp = {
-                .block_size = 16,
-                .record_iv_size = 16,
-                .mac_key_size = SHA_DIGEST_LENGTH,
-                .decrypt = s2n_composite_cipher_aes_sha_decrypt,
-                .encrypt = s2n_composite_cipher_aes_sha_encrypt,
-                .set_mac_write_key = s2n_composite_cipher_aes_sha_set_mac_write_key,
-                .initial_hmac = s2n_composite_cipher_aes_sha_initial_hmac },
+            .block_size = 16,
+            .record_iv_size = 16,
+            .mac_key_size = SHA_DIGEST_LENGTH,
+            .decrypt = s2n_composite_cipher_aes_sha_decrypt,
+            .encrypt = s2n_composite_cipher_aes_sha_encrypt,
+            .set_mac_write_key = s2n_composite_cipher_aes_sha_set_mac_write_key,
+            .initial_hmac = s2n_composite_cipher_aes_sha_initial_hmac },
     .is_available = s2n_composite_cipher_aes128_sha_available,
     .init = s2n_composite_cipher_aes_sha_init,
     .set_encryption_key = s2n_composite_cipher_aes128_sha_set_encryption_key,
@@ -321,17 +318,17 @@ struct s2n_cipher s2n_aes128_sha = {
     .destroy_key = s2n_composite_cipher_aes_sha_destroy_key,
 };
 
-struct s2n_cipher s2n_aes256_sha = {
+const struct s2n_cipher s2n_aes256_sha = {
     .key_material_size = 32,
     .type = S2N_COMPOSITE,
     .io.comp = {
-                .block_size = 16,
-                .record_iv_size = 16,
-                .mac_key_size = SHA_DIGEST_LENGTH,
-                .decrypt = s2n_composite_cipher_aes_sha_decrypt,
-                .encrypt = s2n_composite_cipher_aes_sha_encrypt,
-                .set_mac_write_key = s2n_composite_cipher_aes_sha_set_mac_write_key,
-                .initial_hmac = s2n_composite_cipher_aes_sha_initial_hmac },
+            .block_size = 16,
+            .record_iv_size = 16,
+            .mac_key_size = SHA_DIGEST_LENGTH,
+            .decrypt = s2n_composite_cipher_aes_sha_decrypt,
+            .encrypt = s2n_composite_cipher_aes_sha_encrypt,
+            .set_mac_write_key = s2n_composite_cipher_aes_sha_set_mac_write_key,
+            .initial_hmac = s2n_composite_cipher_aes_sha_initial_hmac },
     .is_available = s2n_composite_cipher_aes256_sha_available,
     .init = s2n_composite_cipher_aes_sha_init,
     .set_encryption_key = s2n_composite_cipher_aes256_sha_set_encryption_key,
@@ -339,17 +336,17 @@ struct s2n_cipher s2n_aes256_sha = {
     .destroy_key = s2n_composite_cipher_aes_sha_destroy_key,
 };
 
-struct s2n_cipher s2n_aes128_sha256 = {
+const struct s2n_cipher s2n_aes128_sha256 = {
     .key_material_size = 16,
     .type = S2N_COMPOSITE,
     .io.comp = {
-                .block_size = 16,
-                .record_iv_size = 16,
-                .mac_key_size = SHA256_DIGEST_LENGTH,
-                .decrypt = s2n_composite_cipher_aes_sha_decrypt,
-                .encrypt = s2n_composite_cipher_aes_sha_encrypt,
-                .set_mac_write_key = s2n_composite_cipher_aes_sha256_set_mac_write_key,
-                .initial_hmac = s2n_composite_cipher_aes_sha_initial_hmac },
+            .block_size = 16,
+            .record_iv_size = 16,
+            .mac_key_size = SHA256_DIGEST_LENGTH,
+            .decrypt = s2n_composite_cipher_aes_sha_decrypt,
+            .encrypt = s2n_composite_cipher_aes_sha_encrypt,
+            .set_mac_write_key = s2n_composite_cipher_aes_sha256_set_mac_write_key,
+            .initial_hmac = s2n_composite_cipher_aes_sha_initial_hmac },
     .is_available = s2n_composite_cipher_aes128_sha256_available,
     .init = s2n_composite_cipher_aes_sha_init,
     .set_encryption_key = s2n_composite_cipher_aes128_sha256_set_encryption_key,
@@ -357,17 +354,17 @@ struct s2n_cipher s2n_aes128_sha256 = {
     .destroy_key = s2n_composite_cipher_aes_sha_destroy_key,
 };
 
-struct s2n_cipher s2n_aes256_sha256 = {
+const struct s2n_cipher s2n_aes256_sha256 = {
     .key_material_size = 32,
     .type = S2N_COMPOSITE,
     .io.comp = {
-                .block_size = 16,
-                .record_iv_size = 16,
-                .mac_key_size = SHA256_DIGEST_LENGTH,
-                .decrypt = s2n_composite_cipher_aes_sha_decrypt,
-                .encrypt = s2n_composite_cipher_aes_sha_encrypt,
-                .set_mac_write_key = s2n_composite_cipher_aes_sha256_set_mac_write_key,
-                .initial_hmac = s2n_composite_cipher_aes_sha_initial_hmac },
+            .block_size = 16,
+            .record_iv_size = 16,
+            .mac_key_size = SHA256_DIGEST_LENGTH,
+            .decrypt = s2n_composite_cipher_aes_sha_decrypt,
+            .encrypt = s2n_composite_cipher_aes_sha_encrypt,
+            .set_mac_write_key = s2n_composite_cipher_aes_sha256_set_mac_write_key,
+            .initial_hmac = s2n_composite_cipher_aes_sha_initial_hmac },
     .is_available = s2n_composite_cipher_aes256_sha256_available,
     .init = s2n_composite_cipher_aes_sha_init,
     .set_encryption_key = s2n_composite_cipher_aes256_sha256_set_encryption_key,
